@@ -74,7 +74,7 @@ class Freebox(IPlugin):
 #[5, 7]
 						# search position '|' dans rs['idx']	
 						# 'http://hd2.freebox.fr/pub/remote_control?code=35782633&key=%s' % (rs))
-							for rx in range rs['idx_sec']:
+							for rx in rs['idx_sec']:
 								log.msg(" rx  :  %s" % (rx)
 								log.msg("idx_sec  :  %s" % (int(rs['idx_sec'])))
 								log.msg("idx  :  %s" % (rs['idx']))
